/*****************************************************************************  
 
Copyright (C) 2010 Lubos Lunak <l.lunak@suse.cz>  
  
Permission is hereby granted, free of charge, to any person obtaining a copy  
of this software and associated documentation files (the "Software"), to deal  
in the Software without restriction, including without limitation the rights  
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell  
copies of the Software, and to permit persons to whom the Software is  
furnished to do so, subject to the following conditions:  
 
The above copyright notice and this permission notice shall be included in  
all copies or substantial portions of the Software.  
 
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR  
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE  
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN  
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN  
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  
 
*****************************************************************************/  
  
#ifndef KSUSEINSTALL_H  
#define KSUSEINSTALL_H  
 
/*  
  
 This API is internal and not stable.  
*/  
 
#include <ksuseinstall_export.h>  
  
#include <QtCore/QStringList>  
 
#include <kdialog.h>  
#include <kservice.h>  
 
class KProcess;  
class KProgressDialog;  
class QLabel;  
class QTreeWidget;  
 
class KSUSEINSTALL_EXPORT KSUSEInstall  
    {  
    public:  
        static bool checkBinaryInstalled( const QString& name, QWidget* parent );  
        static bool installDebuginfo( const QStringList& files, QWidget* parent );  
        static bool canInstallDebuginfo();  
        enum InstallType  
            {  
            PartialInstallAllowed, /// it is ok if at least one item can be installed  
            FullInstallRequired,   /// all requested items must be installed  
            OneItemInstall /// exactly one item in the list must be installed, offer choice if there are more  
            };  
        static bool installCapabilities( const QStringList& capabilities, InstallType type, QWidget* parent );  
        static bool checkMimeTypeInstalled( const QString& mimetype, QWidget* parent );  
    private:  
        static bool globallyDisabled();  
        static bool run( KProcess& proc );  
        static bool performInstallCapabilities( const QStringList& capabilities, InstallType type, QWidget* parent,  
            bool* installationChanges );  
        static QStringList packagesToInstall( const QStringList& capabilities, InstallType type, QWidget* parent,  
            bool* notAvailable, KProgressDialog& progress );  
        struct PackageInstallData;  
        static QList< PackageInstallData > packagesForCapability( const QString& capability );  
        static bool installPackages( const QStringList& packages, QWidget* parent );  
        static bool tryAddRepositories( bool partial, QWidget* parent );  
        static bool mimeTypeInheritanceAllowed( const QString& mimetype );  
        static QString findFallbackMimeType( const QString& mimetype, KService::Ptr handler );  
        static QStringList selectOnePackageToInstall( const QStringList& packages, QWidget* parent );  
        struct PackageInfoData;  
        static QList< PackageInfoData > readPackagesInfo( const QStringList& packages );  
        enum InstallStatus { Available, Installed };  
        class SelectPackageDialog;  
    };  
 
class KSUSEInstall::SelectPackageDialog  
    : public KDialog  
    {  
    Q_OBJECT  
    public:  
        SelectPackageDialog( const QList< PackageInfoData >& data, QWidget* parent );  
        QString selectedPackage() const;  
    private slots:  
        void currentChanged();  
    private:  
        QTreeWidget* list;  
        QLabel* description;  
        QStringList descriptions;  
    };  
 
#endif  
